==> huaweicloudsdkiotanalytics-3.0.79-py2.py3-none-any.whl: huaweicloudsdkiotanalytics/v1/model/add_dev_data_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AddDevDataRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'datasource_id': 'str',
        'body': 'object'
    }

    attribute_map = {
        'datasource_id': 'datasource_id',
        'body': 'body'
    }

    def __init__(self, datasource_id=None, body=None):
        """AddDevDataRequest - a model defined in huaweicloud sdk"""
        
        

        self._datasource_id = None
        self._body = None
        self.discriminator = None

        self.datasource_id = datasource_id
        if body is not None:
            self.body = body

    @property
    def datasource_id(self):
        """Gets the datasource_id of this AddDevDataRequest.

        数据源id

        :return: The datasource_id of this AddDevDataRequest.
        :rtype: str
        """
        return self._datasource_id

    @datasource_id.setter
    def datasource_id(self, datasource_id):
        """Sets the datasource_id of this AddDevDataRequest.

        数据源id

        :param datasource_id: The datasource_id of this AddDevDataRequest.
        :type: str
        """
        self._datasource_id = datasource_id

    @property
    def body(self):
        """Gets the body of this AddDevDataRequest.


        :return: The body of this AddDevDataRequest.
        :rtype: object
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this AddDevDataRequest.


        :param body: The body of this AddDevDataRequest.
        :type: object
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddDevDataRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiotanalytics-3.0.94-py2.py3-none-any.whl: huaweicloudsdkiotanalytics/v1/model/add_dev_data_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AddDevDataRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'datasource_id': 'str',
        'body': 'object'
    }

    attribute_map = {
        'datasource_id': 'datasource_id',
        'body': 'body'
    }

    def __init__(self, datasource_id=None, body=None):
        """AddDevDataRequest

        The model defined in huaweicloud sdk

        :param datasource_id: 数据源id
        :type datasource_id: str
        :param body: Body of the AddDevDataRequest
        :type body: object
        """
        
        

        self._datasource_id = None
        self._body = None
        self.discriminator = None

        self.datasource_id = datasource_id
        if body is not None:
            self.body = body

    @property
    def datasource_id(self):
        """Gets the datasource_id of this AddDevDataRequest.

        数据源id

        :return: The datasource_id of this AddDevDataRequest.
        :rtype: str
        """
        return self._datasource_id

    @datasource_id.setter
    def datasource_id(self, datasource_id):
        """Sets the datasource_id of this AddDevDataRequest.

        数据源id

        :param datasource_id: The datasource_id of this AddDevDataRequest.
        :type datasource_id: str
        """
        self._datasource_id = datasource_id

    @property
    def body(self):
        """Gets the body of this AddDevDataRequest.


        :return: The body of this AddDevDataRequest.
        :rtype: object
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this AddDevDataRequest.


        :param body: The body of this AddDevDataRequest.
        :type body: object
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddDevDataRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
